aboutsummaryrefslogtreecommitdiffstats
path: root/src/jogl/classes/com/jogamp/opengl/util/stereo/StereoDeviceRenderer.java
diff options
context:
space:
mode:
authorSven Gothel <sgothel@jausoft.com>2015-03-21 04:31:27 +0100
committerSven Gothel <sgothel@jausoft.com>2015-03-21 04:31:27 +0100
commit32fc8f3a64cfeee8936af98ae49f8e7c8dfe982f (patch)
tree9f4a250b235bcf6c41bd5c98f19c7e2666e45e57 /src/jogl/classes/com/jogamp/opengl/util/stereo/StereoDeviceRenderer.java
parent2c88b6dfd4eb7e2cd9a50fa48e08ecafc980931a (diff)
Bug 1116 - Add OculusVR DK2 Support - Part-1 (DK2 on DK1 SDK w/o Eye Tracker)
- DK2's screen on X11 (at least) starts in rotated mode, detect and apply MonitorDevice rotation via NEWT's OpenGL StereoDeviceUtil - Move StereoDevice.Config -> StereoDeviceConfig - Expose generic StereoDevice to public: GenericStereoDeviceConfig + GenericStereoDeviceFactory - GenericStereoDeviceFactory exposes public GenericStereoDeviceConfig creation for mono, sbs-stereo and lense-sbs-stereo w/ diff. parameters. - Pass eye surface/texture size for each eye from device to renderer, instead of assuming unified values. - Unify GenericStereoDevice.createRenderer(..) and OVRStereoDevice.createRenderer(..) code
Diffstat (limited to 'src/jogl/classes/com/jogamp/opengl/util/stereo/StereoDeviceRenderer.java')
-rw-r--r--src/jogl/classes/com/jogamp/opengl/util/stereo/StereoDeviceRenderer.java8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/jogl/classes/com/jogamp/opengl/util/stereo/StereoDeviceRenderer.java b/src/jogl/classes/com/jogamp/opengl/util/stereo/StereoDeviceRenderer.java
index 68ae3241b..2078a00a2 100644
--- a/src/jogl/classes/com/jogamp/opengl/util/stereo/StereoDeviceRenderer.java
+++ b/src/jogl/classes/com/jogamp/opengl/util/stereo/StereoDeviceRenderer.java
@@ -155,17 +155,17 @@ public interface StereoDeviceRenderer {
public boolean usesSideBySideStereo();
/**
- * Returns the unified surface size of one eye's a single image in pixel units.
+ * Returns the surface size for each eye's a single image in pixel units.
*/
- public DimensionImmutable getSingleSurfaceSize();
+ public DimensionImmutable[] getEyeSurfaceSize();
/**
* Returns the total surface size required for the complete images in pixel units.
* <p>
* If {@link #usesSideBySideStereo()} the total size spans over both {@link #getSingleSurfaceSize()}, side-by-side.
* </p>
* <p>
* Otherwise the size is equal to {@link #getSingleSurfaceSize()}.
* </p>
*/
public DimensionImmutable getTotalSurfaceSize();
@@ -155,17 +155,17 @@ public interface StereoDeviceRenderer {
* Returns the total surface size required for the complete images in pixel units.
* <p>
- * If {@link #usesSideBySideStereo()} the total size spans over both {@link #getSingleSurfaceSize()}, side-by-side.
+ * If {@link #usesSideBySideStereo()} the total size spans over both {@link #getEyeSurfaceSize()}, side-by-side.
* </p>
* <p>
@@ -155,17 +155,17 @@ public interface StereoDeviceRenderer {
* </p>
* <p>
- * Otherwise the size is equal to {@link #getSingleSurfaceSize()}.
+ * Otherwise the size is equal to {@link #getEyeSurfaceSize()}.
* </p>
*/